@@ -170,8 +170,16 @@ class Fpm:
     for depName, depVersion in deps.items():
       if depName not in self.skipDeps:
         if (depVersion != "from_system"):
-            depVersion = self.stripDashes(depVersion)
-            depsArg.extend(['--depends', self.packagePrefix + depName + ' >= ' + depVersion])
+          depVersion = self.stripDashes(depVersion)
+
+          # Handle "nightly", "daily" prefixes in O2
+          if depName == 'O2':
+            version_split = depVersion.split('_')
+            if version_split[0] == 'daily' or version_split[0] == 'nightly':
+              version_split.pop(0)
+              depVersion = version = '_'.join(version_split)
+
+          depsArg.extend(['--depends', self.packagePrefix + depName + ' >= ' + depVersion])
         else:  # coming from system, get name from dict
           if depName not in self.runtimeDepsDict:
             logging.critical('Could not find system dependency: %s \nDoes it suppose to come from aliBuild?' % (depName))
